@@ -6,7 +6,7 @@ from archinstall.default_profiles.xorg import XorgProfile
 
 class CosmicProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__('cosmic-epoch', ProfileType.DesktopEnv, advanced=True)
+		super().__init__('Cosmic', ProfileType.DesktopEnv)
 
 	@property
 	@override
