@@ -2,6 +2,8 @@ from typing import TYPE_CHECKING
 
 from archinstall.applications.audio import AudioApp
 from archinstall.applications.bluetooth import BluetoothApp
+from archinstall.applications.power_management import PowerManagementApp
+from archinstall.applications.print_service import PrintServiceApp
 from archinstall.lib.models import Audio
 from archinstall.lib.models.application import ApplicationConfiguration
 from archinstall.lib.models.users import User
@@ -25,5 +27,14 @@ class ApplicationHandler:
 				users,
 			)
 
+		if app_config.power_management_config:
+			PowerManagementApp().install(
+				install_session,
+				app_config.power_management_config,
+			)
+
+		if app_config.print_service_config and app_config.print_service_config.enabled:
+			PrintServiceApp().install(install_session)
+
 
 application_handler = ApplicationHandler()
