@@ -422,11 +422,18 @@ class DeviceHandler:
 		cmd: str,
 		info_type: Literal['lv', 'vg', 'pvseg'],
 	) -> LvmVolumeInfo | LvmGroupInfo | LvmPVInfo | None:
-		while True:
+		# Retry for up to 5 mins
+		max_retries = 100
+		for attempt in range(max_retries):
 			try:
 				return self._lvm_info(cmd, info_type)
 			except ValueError:
-				time.sleep(3)
+				if attempt < max_retries - 1:
+					debug(f'LVM info query failed (attempt {attempt + 1}/{max_retries}), retrying in 3 seconds...')
+					time.sleep(3)
+
+		debug(f'LVM info query failed after {max_retries} attempts')
+		return None
 
 	def lvm_vol_info(self, lv_name: str) -> LvmVolumeInfo | None:
 		cmd = f'lvs --reportformat json --unit B -S lv_name={lv_name}'
@@ -457,8 +464,22 @@ class DeviceHandler:
 		SysCommand(cmd)
 
 	def lvm_import_vg(self, vg: LvmVolumeGroup) -> None:
-		cmd = f'vgimport {vg.name}'
+		# Check if the VG is actually exported before trying to import it
+		check_cmd = f'vgs --noheadings -o vg_exported {vg.name}'
 
+		try:
+			result = SysCommand(check_cmd)
+			is_exported = result.decode().strip() == 'exported'
+		except SysCallError:
+			# VG might not exist yet, skip import
+			debug(f'Volume group {vg.name} not found, skipping import')
+			return
+
+		if not is_exported:
+			debug(f'Volume group {vg.name} is already active (not exported), skipping import')
+			return
+
+		cmd = f'vgimport {vg.name}'
 		debug(f'vgimport: {cmd}')
 		SysCommand(cmd)
 
@@ -470,22 +491,25 @@ class DeviceHandler:
 		SysCommand(cmd)
 
 	def lvm_pv_create(self, pvs: Iterable[Path]) -> None:
-		cmd = 'pvcreate ' + ' '.join([str(pv) for pv in pvs])
+		pvs_str = ' '.join([str(pv) for pv in pvs])
+		# Signatures are already wiped by wipefs, -f is just for safety
+		cmd = f'pvcreate -f --yes {pvs_str}'
+		# note flags used in scripting
 		debug(f'Creating LVM PVS: {cmd}')
+		SysCommand(cmd)
 
-		worker = SysCommandWorker(cmd)
-		worker.poll()
-		worker.write(b'y\n', line_ending=False)
+		# Sync with udev to ensure the PVs are visible
+		self.udev_sync()
 
 	def lvm_vg_create(self, pvs: Iterable[Path], vg_name: str) -> None:
 		pvs_str = ' '.join([str(pv) for pv in pvs])
-		cmd = f'vgcreate --yes {vg_name} {pvs_str}'
+		cmd = f'vgcreate --yes --force {vg_name} {pvs_str}'
 
 		debug(f'Creating LVM group: {cmd}')
+		SysCommand(cmd)
 
-		worker = SysCommandWorker(cmd)
-		worker.poll()
-		worker.write(b'y\n', line_ending=False)
+		# Sync with udev to ensure the VG is visible
+		self.udev_sync()
 
 	def lvm_vol_create(self, vg_name: str, volume: LvmVolume, offset: Size | None = None) -> None:
 		if offset is not None:
@@ -729,6 +753,17 @@ class DeviceHandler:
 
 		disk.commit()
 
+		# Wipe filesystem/LVM signatures from newly created partitions
+		# to prevent "signature detected" errors
+		for part_mod in filtered_part:
+			if part_mod.dev_path:
+				debug(f'Wiping signatures from: {part_mod.dev_path}')
+				SysCommand(f'wipefs --all {part_mod.dev_path}')
+
+		# Sync with udev after wiping signatures
+		if filtered_part:
+			self.udev_sync()
+
 	@staticmethod
 	def swapon(path: Path) -> None:
 		try:
