@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import override
 
 from archinstall.lib.disk.disk_menu import DiskLayoutConfigurationMenu
-from archinstall.lib.models.application import ApplicationConfiguration
+from archinstall.lib.models.application import ApplicationConfiguration, ZramConfiguration
 from archinstall.lib.models.authentication import AuthenticationConfiguration
 from archinstall.lib.models.device import DiskLayoutConfiguration, DiskLayoutType, EncryptionType, FilesystemType, PartitionModification
 from archinstall.lib.packages import list_available_packages
@@ -41,10 +41,10 @@ from .translationhandler import Language, tr, translation_handler
 class GlobalMenu(AbstractMenu[None]):
 	def __init__(self, arch_config: ArchConfig) -> None:
 		self._arch_config = arch_config
-		menu_optioons = self._get_menu_options()
+		menu_options = self._get_menu_options()
 
 		self._item_group = MenuItemGroup(
-			menu_optioons,
+			menu_options,
 			sort_items=False,
 			checkmarks=True,
 		)
@@ -56,7 +56,7 @@ class GlobalMenu(AbstractMenu[None]):
 			MenuItem(
 				text=tr('Archinstall language'),
 				action=self._select_archinstall_language,
-				display_action=lambda x: x.display_name if x else '',
+				preview_action=self._prev_archinstall_language,
 				key='archinstall_language',
 			),
 			MenuItem(
@@ -80,7 +80,7 @@ class GlobalMenu(AbstractMenu[None]):
 			),
 			MenuItem(
 				text=tr('Swap'),
-				value=True,
+				value=ZramConfiguration(enabled=True),
 				action=ask_for_swap,
 				preview_action=self._prev_swap,
 				key='swap',
@@ -92,6 +92,14 @@ class GlobalMenu(AbstractMenu[None]):
 				preview_action=self._prev_bootloader_config,
 				key='bootloader_config',
 			),
+			MenuItem(
+				text=tr('Kernels'),
+				value=['linux'],
+				action=select_kernel,
+				preview_action=self._prev_kernel,
+				mandatory=True,
+				key='kernels',
+			),
 			MenuItem(
 				text=tr('Hostname'),
 				value='archlinux',
@@ -118,14 +126,6 @@ class GlobalMenu(AbstractMenu[None]):
 				preview_action=self._prev_applications,
 				key='app_config',
 			),
-			MenuItem(
-				text=tr('Kernels'),
-				value=['linux'],
-				action=select_kernel,
-				preview_action=self._prev_kernel,
-				mandatory=True,
-				key='kernels',
-			),
 			MenuItem(
 				text=tr('Network configuration'),
 				action=ask_to_configure_network,
@@ -239,6 +239,13 @@ class GlobalMenu(AbstractMenu[None]):
 
 		return language
 
+	def _prev_archinstall_language(self, item: MenuItem) -> str | None:
+		if not item.value:
+			return None
+
+		lang: Language = item.value
+		return f'{tr("Language")}: {lang.display_name}'
+
 	def _select_applications(self, preset: ApplicationConfiguration | None) -> ApplicationConfiguration | None:
 		app_config = ApplicationMenu(preset).run()
 		return app_config
@@ -324,6 +331,16 @@ class GlobalMenu(AbstractMenu[None]):
 				output += f'{tr("Audio")}: {audio_config.audio.value}'
 				output += '\n'
 
+			if app_config.print_service_config:
+				output += f'{tr("Print service")}: '
+				output += tr('Enabled') if app_config.print_service_config.enabled else tr('Disabled')
+				output += '\n'
+
+			if app_config.power_management_config:
+				power_management_config = app_config.power_management_config
+				output += f'{tr("Power management")}: {power_management_config.power_management.value}'
+				output += '\n'
+
 			return output
 
 		return None
@@ -367,7 +384,9 @@ class GlobalMenu(AbstractMenu[None]):
 	def _prev_swap(self, item: MenuItem) -> str | None:
 		if item.value is not None:
 			output = f'{tr("Swap on zram")}: '
-			output += tr('Enabled') if item.value else tr('Disabled')
+			output += tr('Enabled') if item.value.enabled else tr('Disabled')
+			if item.value.enabled:
+				output += f'\n{tr("Compression algorithm")}: {item.value.algorithm.value}'
 			return output
 		return None
 
@@ -447,6 +466,10 @@ class GlobalMenu(AbstractMenu[None]):
 			if boot_partition.fs_type not in [FilesystemType.Fat12, FilesystemType.Fat16, FilesystemType.Fat32]:
 				return 'Limine does not support booting with a non-FAT boot partition'
 
+		elif bootloader == Bootloader.Refind:
+			if not SysInfo.has_uefi():
+				return 'rEFInd can only be used on UEFI systems'
+
 		return None
 
 	def _prev_install_invalid_config(self, item: MenuItem) -> str | None:
