@@ -13,7 +13,6 @@ from archinstall.tui.result import ResultType
 from archinstall.tui.types import Alignment, FrameProperties, Orientation, PreviewStyle
 
 from ..locale.utils import list_timezones
-from ..models.audio_configuration import Audio, AudioConfiguration
 from ..models.packages import AvailablePackage, PackageGroup
 from ..output import warn
 from ..translationhandler import Language
@@ -102,29 +101,6 @@ def ask_for_a_timezone(preset: str | None = None) -> str | None:
 			return result.get_value()
 
 
-def ask_for_audio_selection(preset: AudioConfiguration | None = None) -> AudioConfiguration | None:
-	items = [MenuItem(a.value, value=a) for a in Audio]
-	group = MenuItemGroup(items)
-
-	if preset:
-		group.set_focus_by_value(preset.audio)
-
-	result = SelectMenu[Audio](
-		group,
-		allow_skip=True,
-		alignment=Alignment.CENTER,
-		frame=FrameProperties.min(tr('Audio')),
-	).run()
-
-	match result.type_:
-		case ResultType.Skip:
-			return preset
-		case ResultType.Selection:
-			return AudioConfiguration(audio=result.get_value())
-		case ResultType.Reset:
-			raise ValueError('Unhandled result type')
-
-
 def select_language(preset: str | None = None) -> str | None:
 	from ..locale.locale_menu import select_kb_layout
 
@@ -185,7 +161,8 @@ def ask_additional_packages_to_install(
 	package_groups = PackageGroup.from_available_packages(packages)
 
 	# Additional packages (with some light weight error handling for invalid package names)
-	header = tr('Only packages such as base, base-devel, linux, linux-firmware, efibootmgr and optional profile packages are installed.') + '\n'
+	header = tr('Only packages such as base, sudo, linux, linux-firmware, efibootmgr and optional profile packages are installed.') + '\n'
+	header += tr('Note: base-devel is no longer installed by default. Add it here if you need build tools.') + '\n'
 	header += tr('Select any packages from the below list that should be installed additionally') + '\n'
 
 	# there are over 15k packages so this needs to be quick
@@ -247,13 +224,14 @@ def add_number_of_parallel_downloads(preset: int | None = None) -> int | None:
 	header += tr(' - Maximum recommended value : {} ( Allows {} parallel downloads at a time )').format(max_recommended, max_recommended) + '\n'
 	header += tr(' - Disable/Default : 0 ( Disables parallel downloading, allows only 1 download at a time )\n')
 
-	def validator(s: str) -> str | None:
-		try:
-			value = int(s)
-			if value >= 0:
-				return None
-		except Exception:
-			pass
+	def validator(s: str | None) -> str | None:
+		if s is not None:
+			try:
+				value = int(s)
+				if value >= 0:
+					return None
+			except Exception:
+				pass
 
 		return tr('Invalid download number')
 
@@ -290,8 +268,12 @@ def add_number_of_parallel_downloads(preset: int | None = None) -> int | None:
 	return downloads
 
 
-def ask_post_installation() -> PostInstallationAction:
-	header = tr('Installation completed') + '\n\n'
+def ask_post_installation(elapsed_time: float | None = None) -> PostInstallationAction:
+	header = 'Installation completed'
+	if elapsed_time is not None:
+		minutes = int(elapsed_time // 60)
+		seconds = int(elapsed_time % 60)
+		header += f' in {minutes}m{seconds}s' + '\n'
 	header += tr('What would you like to do next?') + '\n'
 
 	items = [MenuItem(action.value, value=action) for action in PostInstallationAction]
