@@ -25,8 +25,8 @@ class ProfileMenu(AbstractSubMenu[ProfileConfiguration]):
 		else:
 			self._profile_config = ProfileConfiguration()
 
-		menu_optioons = self._define_menu_options()
-		self._item_group = MenuItemGroup(menu_optioons, checkmarks=True)
+		menu_options = self._define_menu_options()
+		self._item_group = MenuItemGroup(menu_options, checkmarks=True)
 
 		super().__init__(
 			self._item_group,
