@@ -5,10 +5,16 @@
 #   (4. Added the ~/.config directory as an additional option for future reasons)
 #
 # And Keeping this in dict ensures that variables are shared across imports.
-from pathlib import Path
-from typing import Any
+from typing import TYPE_CHECKING, NotRequired, TypedDict
 
-storage: dict[str, Any] = {
-	"LOG_PATH": Path("/var/log/archinstall"),
-	"LOG_FILE": Path("install.log"),
-}
+if TYPE_CHECKING:
+	from archinstall.lib.boot import Boot
+	from archinstall.lib.installer import Installer
+
+
+class _StorageDict(TypedDict):
+	active_boot: NotRequired['Boot | None']
+	installation_session: NotRequired['Installer']
+
+
+storage: _StorageDict = {}
